@@ -16,9 +16,11 @@ from .utils import TEST_DATA_DIR, TEST_IMAGE_DATA
 from .test_pretrained import check_image_prediction
 
 BUS_INDEX = 779
-BUS_PATH = os.path.join(TEST_IMAGE_DATA, "bus.jpg")
 
+BUS_PATH = os.path.join(TEST_IMAGE_DATA, "bus.jpg")
 MOBILENET_PATH = os.path.join(TEST_DATA_DIR, "mobilenetv2.json.gz")
+TEXT_MODEL_PATH = os.path.join(TEST_DATA_DIR, "text_model.json.gz")
+TWO_FIELD_MODEL_PATH = os.path.join(TEST_DATA_DIR, "image_and_category.json.gz")
 
 
 def make_mobilenet(settings):
@@ -92,3 +94,23 @@ def test_ndarray():
         assert False, 'This "image" should throw an exception'
     except ValueError:
         pass
+
+
+def test_text():
+    with gzip.open(TEXT_MODEL_PATH, "rb") as fin:
+        network = json.load(fin)
+
+    text_model = create_model(network)
+    assert text_model._model is not None
+
+
+def test_image_plus_categorical():
+    with gzip.open(TWO_FIELD_MODEL_PATH, "rb") as fin:
+        network = json.load(fin)
+
+    model = create_model(network)
+
+    # Just test we're getting values that are numeric and reasonable
+    assert 0 < model([BUS_PATH, "f1"])[0][0] < 10
+    assert 0 < model([BUS_PATH, None])[0][0] < 10
+    assert 0 < model([None, None])[0][0] < 10
